@@ -554,21 +554,30 @@ YAHOO.crud.new_livegrid = function(index) {
     
     // must shallow copy so chooser does not get m2m checkbox
     column_defs = [];
+    opts.nVisible = 0;
     for (var i=0; i<opts.column_defs.length; i++) {
         column_defs.push(opts.column_defs[i]);
+        if (!opts.column_defs[i].hidden) {
+            opts.nVisible++;
+        }
     }
     if (opts.rm_button) {
       sm = new YAHOO.crud.livegrid_selection_model();
+      sm.width = 20;
       column_defs.unshift(sm);
     }
     
     //var filters = new Ext.grid.GridFilters({filters:tab.grid.opts.filters});
     //Logger(filters);
-        
+    
+    var colModel = new Ext.grid.ColumnModel(column_defs);
+    // 240 is left menu width plus padding
+    var colAvgWidth = (document.body.clientWidth - 240) / opts.nVisible;
+    colModel.defaultWidth = colAvgWidth;
     gridopts = {
         'el'             : opts.div_id,
         'enableDragDrop' : false,
-        'cm'             : new Ext.grid.ColumnModel(column_defs),
+        'cm'             : colModel,
         'loadMask'       : {
             'msg' : 'Loading...'
         },
@@ -578,7 +587,7 @@ YAHOO.crud.new_livegrid = function(index) {
         //'plugins'        : new Ext.grid.GridFilters({filters:tab.grid.opts.filters}),
         'title'          : opts.title,
         'height'         : 250,
-        'width'          : 625
+        'width'          : 'auto'
 
     };
     if (opts.rm_button) {
@@ -632,13 +641,7 @@ YAHOO.crud.handle_chooser_m2m = function(args) {
     //Logger(args);
 
     var tab = YAHOO.crud.TABS[args.index];
-    //Logger(tab);
-    
-    var pk_vals = [];
-    for(var i=0; i<tab.grid.opts.pk.length; i++) {
-        pk_vals[i] = args.r.get(tab.grid.opts.pk[i]);
-    }
-    var pk = pk_vals.join(';;');
+    var pk  = args.r.id;
        
     //Logger('pk = ' + pk);
     
@@ -669,12 +672,7 @@ YAHOO.crud.handle_chooser_o2m = function(args) {
     Logger(args);
 
     var tab = YAHOO.crud.TABS[args.index];
-    Logger(tab);
-    var pk_vals = [];
-    for(var i=0; i<tab.grid.opts.pk.length; i++) {
-        pk_vals[i] = args.r.get(tab.grid.opts.pk[i]);
-    }
-    var pk = pk_vals.join(';;');
+    var pk  = args.r.id;
        
     Logger('pk = ' + pk);
     
@@ -805,11 +803,13 @@ YAHOO.crud.new_livegrid_chooser = function(index) {
         tab.chooser.cls.superclass.initComponent.call(this);
     }
   });
+  var colModel = new Ext.grid.ColumnModel(tab.grid.opts.column_defs);
+  colModel.defaultWidth = tab.grid.panel.getColumnModel().defaultWidth;
   tab.chooser.opts = {
         'el'             : tab.grid.opts.div_id + '-chooser',
         'enableDragDrop' : false,
         'collapsible'    : true,
-        'cm'             : new Ext.grid.ColumnModel(tab.grid.opts.column_defs),
+        'cm'             : colModel,
         'loadMask'       : {
             'msg' : 'Loading...'
         },
@@ -829,7 +829,7 @@ YAHOO.crud.new_livegrid_chooser = function(index) {
         //'plugins'        : new Ext.grid.GridFilters({filters:tab.grid.opts.filters}),
         'hideParent'     : false,
         'height'         : 250,
-        'width'          : 625
+        'width'          : 'auto'
   };
 
   tab.chooser.panel = new tab.chooser.cls(tab.chooser.opts);
@@ -852,11 +852,7 @@ YAHOO.crud.rm_livegrid_rows = function(args) {
        // make ajax calls to break relationships
        
        for (var i=0; i<rows.length; i++) {
-            var pk_vals  = [];
-            for(var j=0; j<opts.pk.length; j++) {
-                pk_vals[j] = rows[i].get(opts.pk[j]);
-            }
-            var pk = pk_vals.join(';;');
+            var pk = rows[i].id;
             YAHOO.util.Connect.asyncRequest(
                 'POST',
                 opts.parent.url + '/' + opts.foreign.name + '/' + pk + '/remove',
@@ -887,25 +883,12 @@ YAHOO.crud.handle_related_livegrid_click = function(args) {
         Logger('no row passed on click');
         return;
     }
-    
-    //Logger(args);
-    
-    // we want to detect whether the event that triggered this action
-    // was a row-click or a checkbox-selection.
-    // if checkbox, just return and wait for the explicit Remove button click.
-    var tab  = YAHOO.crud.TABS[args.index];
-    var opts = tab.grid.opts;
-    
+        
     if (args.sm.checkBoxClicked == true) {
         return;
     }
     else {
-        YAHOO.crud.redirect_location({
-            pk_fields   : opts.pk,
-            url         : args.url,
-            action      : args.action,
-            r           : args.rec
-        });
+        window.location.href = args.url + args.rec.id + '/' + args.action;
     }
 }
     
